@@ -78,6 +78,7 @@ CONFIG_EXCHANGES = "exchanges"
 CONFIG_EXCHANGE_KEY = "api-key"
 CONFIG_EXCHANGE_SECRET = "api-secret"
 CONFIG_EXCHANGE_PASSWORD = "api-password"
+CONFIG_EXCHANGE_TYPE = "exchange-type"
 CONFIG_EXCHANGE_SANDBOXED = "sandboxed"
 CONFIG_EXCHANGE_FUTURE = "future"
 CONFIG_EXCHANGE_MARGIN = "margin"
@@ -159,6 +160,7 @@ COMMUNITY_TOPS_COUNT = 1000
 DEFAULT_API_KEY = "your-api-key-here"
 DEFAULT_API_SECRET = "your-api-secret-here"
 DEFAULT_API_PASSWORD = "your-api-password-here"
+DEFAULT_EXCHANGE_TYPE = CONFIG_EXCHANGE_SPOT
 DEFAULT_CONFIG_VALUES = {
     DEFAULT_API_KEY,
     DEFAULT_API_SECRET,
